@@ -70,28 +70,3 @@ class UserManagement(APIResource):
         print(' '.join(['user ID:', str(user_id), '- Login successful']))
         return WhatifyResponse(status_code=response.status_code, headers=response.headers)
 
-    @classmethod
-    def get_credentials(cls, user_token: str = None):
-        url = 'connectors/whatify_connect_permissions'
-        requester = APIRequestor()
-        if user_token is None:
-            user_token = toolkit_w.token
-        response = requester.get(url, params={'jwt': user_token})
-        return response
-
-    @classmethod
-    def get_client_path(cls, user_token: str = None):
-        credentials = cls.get_credentials(user_token)
-        os.environ['AWS_ACCESS_KEY_ID'] = credentials['access_key']
-        os.environ['AWS_SECRET_ACCESS_KEY'] = credentials['secret_key']
-        os.environ['AWS_SESSION_TOKEN'] = credentials['session_token']
-        os.environ['AWS_DEFAULT_REGION'] = credentials['region']
-        bucket = credentials['bucket']
-        PATH = credentials['path']
-        s3_path = f's3://{bucket}/{PATH}/'
-        fs = s3fs.S3FileSystem()
-        return fs.ls(s3_path)
-
-
-
-
