@@ -395,8 +395,7 @@ class MyWhatify:
 
     @classmethod
     def get_credentials(cls, api_key: str = None):
-        retval = my_toolkit.Connector.get_credentials(user_token=api_key)
-        return retval
+        return my_toolkit.Connector.get_credentials(user_token=api_key)
 
     @classmethod
     def get_s3_path(cls, user_token: str = None):
